# acdh-bible-pyutils

Utility functions for dealing with biblicial references

## build

```shell
uv build
```


## cheat sheet

### sort imports
```shell
ruff check --select I --fix
```

### format files
```shell
ruff format
```

### run tests

```shell
uv run pytest
```